@@ -219,7 +219,7 @@ class MultiStream(Stream):
                             raise ValueError(f"cannot set volumetric flow by chemical group '{i}'")
             self._init_indexer(flow, phases, chemicals, phase_flows)
             flow = getattr(self, 'i' + name)
-            material_data = self._imol._data * factor
+            material_data = self._imol._data / factor
             if total_flow: material_data *= total_flow / material_data.sum()
             flow._data[:] = material_data
         else:
@@ -228,7 +228,7 @@ class MultiStream(Stream):
         self._sink = self._source = None
         self.reset_cache()
         self._register(ID)
-        self._link = None
+        self._islinked = False
         
     def _init_indexer(self, flow, phases, chemicals, phase_flows):
         if flow == ():
@@ -245,17 +245,25 @@ class MultiStream(Stream):
                 imol = MolarFlowIndexer.from_data(flow, phases, chemicals)
         self._imol = imol
     
-    def _get_property_cache(self, name):
+    def _get_property_cache(self, name, flow=False):
         property_cache = self._property_cache
         thermal_condition = self._thermal_condition
         imol = self._imol
         data = imol._data
+        total = data.sum()
+        if total == 0.: return 0.
+        composition = data / total
         literal = (imol._phases, thermal_condition._T, thermal_condition._P)
-        last_literal, last_data = self._property_cache_key
-        if literal == last_literal and (data == last_data).all():
-            return property_cache.get(name) 
+        last_literal, last_composition, last_total = self._property_cache_key
+        if literal == last_literal and (composition - last_composition).all():
+            prop = property_cache.get(name)
+            if not prop: return prop
+            if flow:
+                return prop * total / last_total
+            else:
+                return prop
         else:
-            self._property_cache_key = (literal, data.copy())
+            self._property_cache_key = (literal, composition, total)
             property_cache.clear()
             return None
     
@@ -284,7 +292,8 @@ class MultiStream(Stream):
             stream = streams[phase]
         else:
             stream = Stream.__new__(Stream)
-            stream._ID = stream._link = stream._sink = stream._source = None
+            stream._ID = stream._sink = stream._source = None
+            stream._islinked = False
             stream._imol = self._imol.get_phase(phase)
             stream._thermal_condition = self._thermal_condition
             stream._thermo = self._thermo
@@ -292,7 +301,7 @@ class MultiStream(Stream):
             stream._dew_point_cache = self._dew_point_cache
             stream._property_cache = {}
             stream.characterization_factors = {}
-            stream._property_cache_key = None, None
+            stream._property_cache_key = None, None, None
             streams[phase] = stream
         return stream
     
@@ -407,7 +416,6 @@ class MultiStream(Stream):
             self.phase = phases[0]
         phases = phase_tuple(phases)
         if phases != self.phases:
-            if self._link: raise RuntimeError('cannot convert linked stream')
             self._imol = self._imol.to_material_indexer(phases)
             self.reset_cache()
     
@@ -437,7 +445,7 @@ class MultiStream(Stream):
     @property
     def H(self):
         """[float] Enthalpy flow rate in kJ/hr."""
-        H = self._get_property_cache('H')
+        H = self._get_property_cache('H', True)
         if H is None:
             self._property_cache['H'] = H = self.mixture.xH(self._imol, *self._thermal_condition)
         return H
@@ -448,14 +456,14 @@ class MultiStream(Stream):
     @property
     def S(self):
         """[float] Absolute entropy flow rate in kJ/hr."""
-        S = self._get_property_cache('S')
+        S = self._get_property_cache('S', True)
         if S is None:
             self._property_cache['S'] = S = self.mixture.xS(self._imol, *self._thermal_condition)
         return S
     @property
     def C(self):
         """[float] Heat capacity flow rate in kJ/hr."""
-        C = self._get_property_cache('C')
+        C = self._get_property_cache('C', True)
         if C is None:
             self._property_cache['C'] = C = self.mixture.xCn(self._imol, self.T)
         return C
@@ -665,6 +673,8 @@ class MultiStream(Stream):
         """
         if self.chemicals is not other.chemicals:
             raise ValueError('other stream must have the same chemicals defined to copy flow')
+        other_ismultistream = isinstance(other, MultiStream)
+        if other_ismultistream: self.phases = [*self.phases, *other.phases]
         IDs_index = self.chemicals.get_index(IDs)
         phase_index = self.imol.get_phase_index(phase)
         data = self.imol.data
@@ -673,9 +683,7 @@ class MultiStream(Stream):
             data = self.imol.data
             other_data = other.imol.data
             original_data = data.copy()
-            if isinstance(other, MultiStream):
-                if self.phases != other.phases:
-                    raise ValueError('other stream must have the same phases defined to copy flow')
+            if other_ismultistream:
                 data[:] = other_data
                 data[phase_index, IDs_index] = original_data[phase_index, IDs_index]
                 if remove:
@@ -690,9 +698,7 @@ class MultiStream(Stream):
                     excluded_data = other_data[IDs_index]
                     other_data[:] = 0.
                     other_data[IDs_index] = excluded_data   
-        elif isinstance(other, MultiStream):
-            if self.phases != other.phases:
-                raise ValueError('other stream must have the same phases defined to copy flow')
+        elif other_ismultistream:
             data[phase_index, IDs_index] = other_data[phase_index, IDs_index]
             if remove: other_data[phase_index, IDs_index] = 0.
         else:
@@ -853,14 +859,23 @@ class MultiStream(Stream):
     @property
     def vle(self):
         """[VLE] An object that can perform vapor-liquid equilibrium on the stream."""
+        phases = self.phases
+        if 'l' not in phases or 'g' not in phases: 
+            self.phases = [*phases, 'l', 'g']
         return self._vle_cache.retrieve()
     @property
     def lle(self):
         """[LLE] An object that can perform liquid-liquid equilibrium on the stream."""
+        phases = self.phases
+        if 'l' not in phases or 'L' not in phases: 
+            self.phases = [*phases, 'l', 'L']
         return self._lle_cache.retrieve()
     @property
     def sle(self):
         """[SLE] An object that can perform solid-liquid equilibrium on the stream."""
+        phases = self.phases
+        if 's' not in phases or 'l' not in phases: 
+            self.phases = [*phases, 's', 'l']
         return self._sle_cache.retrieve()
     
     ### Casting ###
@@ -883,7 +898,6 @@ class MultiStream(Stream):
     @phase.setter
     def phase(self, phase):
         if len(phase) > 1: self.phases = phase
-        if self._link: raise RuntimeError('cannot convert linked stream')
         self._imol = self._imol.to_chemical_indexer(phase)
         self._streams.clear()
         self.__class__ = Stream
