@@ -13,7 +13,7 @@ from ._chemicals import Chemicals
 from .mixture import Mixture
 from .utils import read_only, cucumber
 
-__all__ = ('Thermo',)
+__all__ = ('Thermo', 'IdealThermo')
 
 
 @cucumber # Just means you can pickle it
@@ -65,15 +65,12 @@ class Thermo:
         
     >>> ideal = thermo.ideal()
     >>> ideal.show()
-    Thermo(
+    IdealThermo(
         chemicals=CompiledChemicals([Ethanol, Water]),
         mixture=Mixture(
             rule='ideal', ...
             include_excess_energies=False
         ),
-        Gamma=IdealActivityCoefficients,
-        Phi=IdealFugacityCoefficients,
-        PCF=IdealPoyintingCorrectionFactors
     )
     
     Thermodynamic equilibrium results are affected by the choice of property package:
@@ -129,7 +126,7 @@ class Thermo:
         Class for computing poynting correction factors.
     
     """
-    __slots__ = ('chemicals', 'mixture', 'Gamma', 'Phi', 'PCF') 
+    __slots__ = ('chemicals', 'mixture', 'Gamma', 'Phi', 'PCF', '_ideal') 
     
     def __init__(self, chemicals, mixture=None,
                  Gamma=eq.DortmundActivityCoefficients,
@@ -157,17 +154,38 @@ class Thermo:
         setattr(self, 'Gamma', Gamma)
         setattr(self, 'Phi', Phi)
         setattr(self, 'PCF', PCF)
+        setattr(self, '_ideal', None)
+    
+    def subset(self, chemicals):
+        if chemicals is self.chemicals: return self
+        if not isinstance(chemicals, Chemicals): chemicals = Chemicals(chemicals)
+        groups = [(name, index) for name, index in self.chemicals._index.items() 
+                  if isinstance(index, list)]
+        chemicals.compile(skip_checks=True)
+        CASs = self.chemicals.CASs
+        for name, index in groups:
+            group_CASs = [CASs[i] for i in index]
+            chemicals.define_group(name, [i for i in group_CASs if i in chemicals])
+        cls = self.__class__
+        new = cls.__new__(cls)
+        setattr = object.__setattr__
+        setattr(new, 'chemicals', chemicals)
+        setattr(new, 'mixture', self.mixture.from_chemicals(chemicals))
+        setattr(new, 'Gamma', self.Gamma)
+        setattr(new, 'Phi', self.Phi)
+        setattr(new, 'PCF', self.PCF)
+        setattr(new, '_ideal', None)
+        return new
     
     def ideal(self):
         """Ideal thermodynamic property package."""
-        cls = self.__class__
-        ideal = cls.__new__(cls)
-        setattr = object.__setattr__
-        setattr(ideal, 'chemicals', self.chemicals)
-        setattr(ideal, 'mixture', self.mixture)
-        setattr(ideal, 'Gamma', eq.IdealActivityCoefficients)
-        setattr(ideal, 'Phi', eq.IdealFugacityCoefficients)
-        setattr(ideal, 'PCF', eq.IdealPoyintingCorrectionFactors)
+        ideal = self._ideal
+        if not ideal: 
+            ideal = IdealThermo.__new__(IdealThermo)
+            setattr = object.__setattr__
+            setattr(ideal, 'chemicals', self.chemicals)
+            setattr(ideal, 'mixture', self.mixture)
+            setattr(self, '_ideal', ideal)
         return ideal
     
     def as_chemical(self, chemical):
@@ -214,4 +232,85 @@ class Thermo:
               f"    Phi={self.Phi.__name__},\n"
               f"    PCF={self.PCF.__name__}\n"
                ")")
+    _ipython_display_ = show
+    
+@cucumber # Just means you can pickle it
+@read_only
+class IdealThermo:
+    """
+    Create a Thermo object that defines a thermodynamic property package
+    
+    Parameters
+    ----------
+    chemicals : Iterable[:class:`~thermosteam.Chemical` or str]
+        Pure component chemical data.
+    mixture : :class:`~thermosteam.mixture.Mixture`, optional
+        Calculates mixture properties.
+    cache : optional
+        Whether or not to use cached chemicals.
+    skip_checks : bool, optional
+        Whether to skip checks for missing or invalid properties.
+    
+    
+    Attributes
+    ----------
+    chemicals : Chemicals or Iterable[str]
+        Pure component chemical data.
+    mixture : Mixture, optional
+        Calculates mixture properties.
+        
+    """
+    __slots__ = ('chemicals', 'mixture') 
+    
+    Gamma = eq.IdealActivityCoefficients
+    Phi = eq.IdealFugacityCoefficients
+    PCF = eq.IdealPoyintingCorrectionFactors
+    as_chemical = Thermo.as_chemical
+    
+    def __init__(self, chemicals, mixture=None,
+                 cache=None,
+                 skip_checks=False):
+        if not isinstance(chemicals, Chemicals): chemicals = Chemicals(chemicals, cache)
+        if not mixture:
+            mixture = Mixture.from_chemicals(chemicals)
+        elif not isinstance(mixture, Mixture): # pragma: no cover
+            raise ValueError(f"mixture must be a '{Mixture.__name__}' object")
+        chemicals.compile(skip_checks=skip_checks)
+        setattr = object.__setattr__
+        setattr(self, 'chemicals', chemicals)
+        setattr(self, 'mixture', mixture)
+    
+    def subset(self, chemicals):
+        if chemicals is self.chemicals: return self
+        if not isinstance(chemicals, Chemicals): chemicals = Chemicals(chemicals)
+        groups = [(name, index) for name, index in self.chemicals._index.items() 
+                  if isinstance(index, list)]
+        chemicals.compile(skip_checks=True)
+        CASs = self.chemicals.CASs
+        for name, index in groups:
+            group_CASs = [CASs[i] for i in index]
+            chemicals.define_group(name, [i for i in group_CASs if i in chemicals])
+        cls = self.__class__
+        new = cls.__new__(cls)
+        setattr = object.__setattr__
+        setattr(new, 'chemicals', chemicals)
+        setattr(new, 'mixture', self.mixture.from_chemicals(chemicals))
+        return new
+    
+    def ideal(self):
+        """Ideal thermodynamic property package."""
+        return self
+    
+    def __repr__(self):
+        return f"{type(self).__name__}(chemicals={self.chemicals}, mixture={self.mixture})"
+    
+    def show(self):
+        try:
+            mixture_info = self.mixture._info().replace('\n', '\n    ')
+        except: # pragma: no cover
+            mixture_info = str(self.mixture)
+        print(f"{type(self).__name__}(\n"
+              f"    chemicals={self.chemicals},\n"
+              f"    mixture={mixture_info},\n"
+               ")")
     _ipython_display_ = show
\ No newline at end of file
