@@ -29,17 +29,14 @@ def vle_domain(chemicals):
     -------
     Tmin : float
         Minimum temperature [K].
-    Tmax : TYPE
+    Tmax : float
         Maximum temperature [K].
 
     """
     Psats = [i.Psat for i in chemicals]
     Tmax_Psat = min([i.Tmax for i in Psats])
-    Tmax_Cn = min([(i.Cn.Tmax if i.locked_state else min(i.Cn.l.Tmax, i.Cn.g.Tmax)) for i in chemicals])
-    Tmax = min(Tmax_Psat, Tmax_Cn, Tmax_limit) - 1e-2
+    Tmax = min(Tmax_Psat, Tmax_limit) - 1e-2
     
     Tmin_Psat = max([i.Tmin for i in Psats])
-    Tmin_Cn = max([(i.Cn.Tmin if i.locked_state else max(i.Cn.l.Tmin, i.Cn.g.Tmin)) for i in chemicals])
-    Tmin = max(Tmin_Psat, Tmin_Cn, Tmin_limit) + 1e-2
-    
+    Tmin = max(Tmin_Psat, Tmin_limit) + 1e-2
     return (Tmin, Tmax)
\ No newline at end of file
