@@ -435,16 +435,6 @@ class VLE(Equilibrium, phases='lg'):
         elif P > Psat + tol:
             self._liquid_mol[self._index] = self._mol_vle
             self._vapor_mol[self._index] = 0
-        else:
-            pass
-            # raise RuntimeError(
-            #     'VLE of a one component mixture at the bubble point '
-            #     '(which is also the dew point) results in an undetermined '
-            #     'vapor fraction'
-            # )
-            # L_over_F = (P - Psat + tol) / (2 * tol)
-            # self._liquid_mol[self._index] = liq = L_over_F * self._mol_vle
-            # self._vapor_mol[self._index] = self._mol_vle - liq
     
     def _set_TV_chemical(self, T, V):
         # Set vapor fraction
@@ -826,8 +816,9 @@ class VLE(Equilibrium, phases='lg'):
                 def f(V):
                     vapor_mol[index] = V * mol
                     liquid_mol[index] = (1 - V) * mol
-                    return self.mixture.xH(self._phase_data, T_dew, P)/self._F_mass - H_hat
+                    return self.mixture.xH(self._phase_data, T, P)/self._F_mass - H_hat
                 self._T = thermal_condition.T = T
+                
                 y0 = f(0.)
                 if y0 > 0.:
                     self._T = thermal_condition.T = self.mixture.xsolve_T(
