@@ -12,15 +12,18 @@ from . import thermo_user
 from . import read_only
 from . import registered
 from . import forward
+from . import units_of_measure
 
 __all__ = (*chemicals_user.__all__,
            *thermo_user.__all__,
            *read_only.__all__,
            *registered.__all__,
-           *forward.__all__)
+           *forward.__all__,
+           *units_of_measure.__all__)
 
 from .registered import *
 from .chemicals_user import *
 from .thermo_user import *
 from .read_only import *
-from .forward import *
\ No newline at end of file
+from .forward import *
+from .units_of_measure import *
\ No newline at end of file
